@@ -7,7 +7,7 @@ import math
 from torch.autograd import Variable
 import torch.utils.model_zoo as model_zoo
 from UNet.model import *
-from UNet.train import *
+from UNet.train import train
 from UNetPP import *
 from PointNet.model import *
 from StackGAN import *
